predicate

package
v0.0.0-...-2d35685 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 9, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Overview

Package predicate implements event filtering predicates for various Kubernetes resources used by the OADP VM file restore controller.

Package predicate implements event filtering predicates for various Kubernetes resources used by the OADP VM file restore controller.

Package predicate implements event filtering predicates for various Kubernetes resources used by the OADP VM file restore controller.

Package predicate implements event filtering predicates for various Kubernetes resources used by the OADP VM file restore controller.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type NamespacePredicate

type NamespacePredicate struct {
	Namespace string
}

NamespacePredicate filters events to only accept objects from a specific namespace

func (NamespacePredicate) Create

func (p NamespacePredicate) Create(evt event.CreateEvent) bool

Create event filter only accepts objects from the specified namespace

func (NamespacePredicate) Delete

func (p NamespacePredicate) Delete(evt event.DeleteEvent) bool

Delete event filter only accepts objects from the specified namespace

func (NamespacePredicate) Generic

func (p NamespacePredicate) Generic(evt event.GenericEvent) bool

Generic determines whether to process generic events from the specified namespace

func (NamespacePredicate) Update

Update event filter only accepts objects from the specified namespace

type RoutePredicate

type RoutePredicate struct{}

RoutePredicate contains event filters for OpenShift Route objects owned by VirtualMachineFileRestore

func (RoutePredicate) Create

func (p RoutePredicate) Create(evt event.CreateEvent) bool

Create event filter only accepts Routes with VMFR labels

func (RoutePredicate) Delete

func (p RoutePredicate) Delete(evt event.DeleteEvent) bool

Delete event filter only accepts Routes with VMFR labels

func (RoutePredicate) Generic

func (p RoutePredicate) Generic(evt event.GenericEvent) bool

Generic determines whether to process generic Route events

func (RoutePredicate) Update

Update event filter only accepts Routes with VMFR labels and status changes

type ServicePredicate

type ServicePredicate struct{}

ServicePredicate contains event filters for Service objects owned by VirtualMachineFileRestore

func (ServicePredicate) Create

func (p ServicePredicate) Create(evt event.CreateEvent) bool

Create event filter only accepts Services with VMFR labels

func (ServicePredicate) Delete

func (p ServicePredicate) Delete(evt event.DeleteEvent) bool

Delete event filter only accepts Services with VMFR labels

func (ServicePredicate) Generic

func (p ServicePredicate) Generic(evt event.GenericEvent) bool

Generic determines whether to process generic Service events

func (ServicePredicate) Update

Update event filter only accepts Services with VMFR labels

type VeleroRestorePredicate

type VeleroRestorePredicate struct {
	OADPNamespace string
}

VeleroRestorePredicate contains event filters for Velero Restore objects

func (VeleroRestorePredicate) Create

func (VeleroRestorePredicate) Delete

Delete determines whether to process Velero Restore deletion events

func (VeleroRestorePredicate) Generic

Generic determines whether to process generic Velero Restore events

func (VeleroRestorePredicate) Update

Update event filter only accepts Velero Restore update events from OADP namespace and from Velero Restores that have required metadata and VMFR label

Jump to